=======
History
=======

0.1.0 (2020-01-02)
------------------

* First release on PyPI.

0.2.0 (2018-02-13)
------------------

* Major feature implementation and documentation
* Static typing
* Testing - 44% coverage


0.2.3 (2020-03-28)
------------------

* Testing up to 75%
* Exogenous variable support
* Extensive docs


0.3.0 (2020-03-28)
------------------

* Parallel and distributed training


0.4.0 (2020-03-28)
------------------

* Testing for all reconciliation methods, line coverage > 80%


0.4.1 (2020-03-28)
------------------

* Python 3.6 support


0.5.2 (2020-03-28)
------------------

* Added support for no revision, thanks @ryanvolpi
* Added multiple example at https://github.com/carlomazzaferro/scikit-hts-examples, thanks @vtoliveira
* Logging fixes and usability improvements


0.5.3 (2021-02-23)
------------------

* Support for grouped time series, thanks to @noahsa! See: https://github.com/carlomazzaferro/scikit-hts/pull/51

0.5.4 (2021-04-20)
------------------

* Fixed long-standing BU forcasting bug, thanks to @javierhuertay! See: https://github.com/carlomazzaferro/scikit-hts/issues/35

